@@ -1,15 +1,15 @@
 #' @templateVar name_model_full Pareto/NBD
 #' @templateVar name_class_clvmodel clv.model.pnbd.no.cov
-#' @template template_class_clvfittedmodels
+#' @template template_class_clvfittedtransactionmodels
 #'
 #' @template template_slot_pnbdcbs
 #'
-#' @seealso \link{clv.fitted-class}, \link{clv.model.pnbd.no.cov-class}, \link{clv.pnbd.static.cov-class}, \link{clv.pnbd.dynamic.cov-class}
+#' @seealso \linkS4class{clv.fitted.transactions}, \linkS4class{clv.model.pnbd.no.cov}, \linkS4class{clv.pnbd.static.cov}, \linkS4class{clv.pnbd.dynamic.cov}
 #'
 #' @keywords internal
 #' @importFrom methods setClass
-#' @include class_clv_model_pnbd.R class_clv_data.R class_clv_fitted.R
-setClass(Class = "clv.pnbd", contains = "clv.fitted",
+#' @include class_clv_model_pnbd.R class_clv_data.R class_clv_fitted_transactions.R
+setClass(Class = "clv.pnbd", contains = "clv.fitted.transactions",
          slots = c(
            cbs = "data.table"),
 
@@ -27,7 +27,7 @@ clv.pnbd <- function(cl, clv.data){
   clv.model   <- clv.model.pnbd.no.cov()
 
   return(new("clv.pnbd",
-             clv.fitted(cl=cl, clv.model=clv.model, clv.data=clv.data),
+             clv.fitted.transactions(cl=cl, clv.model=clv.model, clv.data=clv.data),
              cbs = dt.cbs.pnbd))
 }
 
@@ -42,25 +42,17 @@ pnbd_cbs <- function(clv.data){
   #     x:        Number of repeat transactions := Number of actual transactions - 1
   #     t.x:      Time between first actual and last transaction
   #     T.cal:    Time between first actual transaction and end of calibration period
-  #     Spending: Average (mean) spending per transaction (of all transactions, not only repeat)
   #
   #     All time is expressed in time units
 
-  trans.dt <- clv.data@data.transactions[Date <= clv.data@clv.time@timepoint.estimation.end]
+  trans.dt <- clv.data.get.transactions.in.estimation.period(clv.data = clv.data)
 
   #Initial cbs, for every Id a row
-  if(clv.data.has.spending(clv.data)){
-    cbs <- trans.dt[ , list(x                        =.N,
-                            date.first.actual.trans  = min(Date),
-                            date.last.transaction    = max(Date),
-                            Spending                 = mean(Price, na.rm=TRUE)),
-                     by="Id"]
-  }else{
-    cbs <- trans.dt[ , list(x                        =.N,
-                            date.first.actual.trans  = min(Date),
-                            date.last.transaction    = max(Date)),
-                     by="Id"]
-  }
+  cbs <- trans.dt[ , list(x                        =.N,
+                          date.first.actual.trans  = min(Date),
+                          date.last.transaction    = max(Date)),
+                   by="Id"]
+
 
   # Only repeat transactions -> Number of transactions - 1
   cbs[, x := x - 1]
@@ -68,12 +60,10 @@ pnbd_cbs <- function(clv.data){
   # t.x, T.cal
   cbs[, ':='(t.x      = clv.time.interval.in.number.tu(clv.time=clv.data@clv.time, interv=interval(start = date.first.actual.trans, end = date.last.transaction)),
              T.cal    = clv.time.interval.in.number.tu(clv.time=clv.data@clv.time, interv=interval(start = date.first.actual.trans, end = clv.data@clv.time@timepoint.estimation.end)))]
+  cbs[, date.last.transaction := NULL]
 
   setkeyv(cbs, c("Id", "date.first.actual.trans"))
-  if(clv.data.has.spending(clv.data))
-    setcolorder(cbs, c("Id","x","t.x","T.cal","Spending","date.first.actual.trans", "date.last.transaction"))
-  else
-    setcolorder(cbs, c("Id","x","t.x","T.cal", "date.first.actual.trans", "date.last.transaction"))
+  setcolorder(cbs, c("Id","x","t.x","T.cal", "date.first.actual.trans"))
 
   return(cbs)
 }
