@@ -1,5 +1,5 @@
 fct.testthat.runability.nocov.without.spending.data <- function(method, data.transactions){
-  test_that("Works without spending data",{
+  test_that("Fit works without spending data",{
     skip_on_cran()
     skip_on_ci()
     skip_on_covr()
@@ -30,6 +30,12 @@ fct.testthat.runability.nocov.predict.fit.no.spending.but.newdata.spending <- fu
 }
 
 
+fct.helper.create.clvdata.cdnow <- function(data.cdnow, estimation.split = 37){
+  expect_silent(clv.cdnow <- clvdata(data.transactions = data.cdnow, date.format = "ymd", time.unit = "w",
+                                     estimation.split = estimation.split))
+  return(clv.cdnow)
+}
+
 fct.helper.create.fake.transdata <- function(data){
   set.seed(0xcaffe) # hipster seed
   expect_silent(dt.newdata.trans <- rbindlist(lapply(LETTERS, function(cid){
@@ -54,7 +60,7 @@ fct.helper.create.fake.newdata.nocov <- function(data, estimation.split){
 
 
 fct.testthat.runability.nocov <- function(name.model, method, cdnow,
-                                          has.DERT, has.cor,
+                                          has.cor,
                                           start.params.model,
                                           failed.optimization.methods.expected.message){
 
@@ -69,7 +75,7 @@ fct.testthat.runability.nocov <- function(name.model, method, cdnow,
 
   param.names <- names(start.params.model)
   l.args.test.all.s3 <- list(full.names = param.names, clv.newdata.nohold = clv.newdata.nohold,
-                             clv.newdata.withhold = clv.newdata.withhold, DERT.not.implemented = !has.DERT)
+                             clv.newdata.withhold = clv.newdata.withhold)
 
   # Common tests ------------------------------------------------------------------------------------------------------------
   fct.testthat.runability.clvfitted.out.of.the.box.no.hold(method = method, clv.data.noholdout = clv.data.cdnow.noholdout,
@@ -104,14 +110,12 @@ fct.testthat.runability.nocov <- function(name.model, method, cdnow,
                                                   clv.data.holdout = clv.data.cdnow.withholdout,
                                                   clv.newdata.nohold = clv.newdata.nohold,
                                                   clv.newdata.withhold = clv.newdata.withhold,
-                                                  DERT.not.implemented = !has.DERT,
                                                   names.params.model = names(start.params.model))
 
     fct.testthat.runability.common.works.with.cor.start.params(method = method,
                                                                clv.data.holdout = clv.data.cdnow.withholdout,
                                                                clv.newdata.nohold = clv.newdata.nohold,
                                                                clv.newdata.withhold = clv.newdata.withhold,
-                                                               DERT.not.implemented = !has.DERT,
                                                                names.params.model = names(start.params.model))
   }
 }
