@@ -1,8 +1,6 @@
 data("cdnow")
 data("apparelTrans") # for years
 
-# context("Correctness - clvdata - clvdata")
-
 # estimation.split ---------------------------------------------------------------------
 context("Correctness - clvdata - estimation.split")
 
@@ -398,30 +396,3 @@ test_that("Aggregating first and removing after removes all first transactions",
 })
 
 
-# summary ---------------------------------------------------------------------------------------------------------
-context("Correctness - clvdata - summary")
-test_that("Zero repeaters are counted correctly", {
-  skip_on_cran()
-
-  fct.verify.zero.repeaters <- function(date.estimation.split){
-    expect_silent(clv.cdnow <- clvdata(cdnow, date.format = "ymd", time.unit = "w", estimation.split = date.estimation.split))
-    expect_silent(res.sum <- summary(clv.cdnow))
-
-    if(!is.null(date.estimation.split)){
-      num.zero.rep <- cdnow[Date <= date.estimation.split, .N, by = "Id"][N == 1, .N]
-      perc.zero.rep <- round(num.zero.rep / cdnow[Date <= date.estimation.split, uniqueN(Id)], 2)
-      expect_true(num.zero.rep == res.sum$descriptives.transactions[Name == "Total # zero repeaters", as.numeric(Estimation)])
-      expect_true(perc.zero.rep == round(res.sum$descriptives.transactions[Name == "Percentage # zero repeaters", as.numeric(Estimation)], 2))
-    }else{
-      num.zero.rep <- cdnow[, .N, by = "Id"][N == 1, .N]
-      perc.zero.rep <- round(num.zero.rep / cdnow[, uniqueN(Id)], 2)
-      expect_true(num.zero.rep == res.sum$descriptives.transactions[Name == "Total # zero repeaters", as.numeric(Total)])
-      expect_true(perc.zero.rep == round(res.sum$descriptives.transactions[Name == "Percentage # zero repeaters", as.numeric(Total)], 2))
-    }
-  }
-
-  # Overall
-  fct.verify.zero.repeaters(date.estimation.split = NULL)
-  # In estimation period
-  fct.verify.zero.repeaters(date.estimation.split = lubridate::ymd("1997-09-17"))
-})
