@@ -614,7 +614,7 @@ test_that("Fails if not in transaction data", {
 
 test_that("Has default argument Id",{
   default.arg <- eval(formals(SetDynamicCovariates)[["name.id"]])
-  expect_is(default.arg, "character")
+  expect_true(is.character(default.arg))
   expect_true(default.arg == "Id")
 })
 
@@ -663,7 +663,7 @@ test_that("Fails if not in transaction data", {
 
 test_that("Has default argument Id",{
   default.arg <- eval(formals(SetDynamicCovariates)[["name.date"]])
-  expect_is(default.arg, "character")
+  expect_true(is.character(default.arg))
   expect_true(default.arg == "Date")
 })
 
